"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DatabaseConnection = void 0;
const mongodb_1 = require("./mongodb");
const sql_1 = require("./sql");
const errorBuilder_1 = require("../errorBuilder");
const metadata_1 = require("../metadata");
const sequelize_1 = require("sequelize");
const decorators_1 = require("../decorators");
const di_1 = require("../di");
let DatabaseConnection = exports.DatabaseConnection = class DatabaseConnection {
    constructor() { }
    init(dbConfig) {
        return __awaiter(this, void 0, void 0, function* () {
            let db;
            let client;
            switch (dbConfig.TYPE) {
                case "mongodb":
                    const mongodb = yield (0, mongodb_1.connectMongoDb)({
                        database: dbConfig.DATABASE,
                        host: dbConfig.HOST,
                        port: dbConfig.PORT,
                        username: dbConfig.USERNAME,
                        password: dbConfig.PASSWORD
                    });
                    db = mongodb.db;
                    client = mongodb.client;
                    break;
                case "mysql":
                    db = yield (0, sql_1.connectDatabaseSql)({
                        database: dbConfig.DATABASE,
                        host: dbConfig.HOST,
                        port: dbConfig.PORT,
                        username: dbConfig.USERNAME,
                        password: dbConfig.PASSWORD,
                        type: "mysql",
                        isLog: !!dbConfig.IS_LOG
                    });
                    break;
                case "postgres":
                    db = yield (0, sql_1.connectDatabaseSql)({
                        database: dbConfig.DATABASE,
                        host: dbConfig.HOST,
                        port: dbConfig.PORT,
                        username: dbConfig.USERNAME,
                        password: dbConfig.PASSWORD,
                        type: "postgres",
                        isLog: !!dbConfig.IS_LOG
                    });
                    break;
                default:
                    throw errorBuilder_1.ErrorBuilder.validator("No DB connection");
            }
            this.dbConnection = {
                db,
                client,
                type: dbConfig.TYPE
            };
            di_1.ServiceProvider.getInstance(metadata_1.Metadata).setDB(this.dbConnection);
        });
    }
    transaction() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.dbConnection instanceof sequelize_1.Sequelize) {
                return this.dbConnection.transaction();
            }
            // if ()
            throw errorBuilder_1.ErrorBuilder.validator("The database connection not supported transaction");
        });
    }
};
exports.DatabaseConnection = DatabaseConnection = __decorate([
    (0, decorators_1.Register)(),
    __metadata("design:paramtypes", [])
], DatabaseConnection);
