"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ServiceProvider = exports.InjectionMode = void 0;
const errorBuilder_1 = require("../errorBuilder");
const injector_1 = require("./injector");
const constants_1 = require("../metadata/constants");
const configuration_1 = require("../configs/configuration");
const events_1 = __importDefault(require("events"));
var InjectionMode;
(function (InjectionMode) {
    InjectionMode["TRANSIENT"] = "transient";
    InjectionMode["SINGLETON"] = "singleton";
})(InjectionMode || (exports.InjectionMode = InjectionMode = {}));
class ServiceProvider {
    static register(constructorFn, mode = InjectionMode.SINGLETON, alias) {
        const dependencies = Reflect.getMetadata(constants_1.MetadataKeys.PARAM_TYPE, constructorFn) || [];
        const singletonInstance = mode == InjectionMode.SINGLETON ? ServiceProvider.injectableRegistry.resolve(constructorFn, false, alias) : undefined;
        if (!ServiceProvider.app.filter(e => e.singletonInstance == singletonInstance).length) {
            ServiceProvider.app.push({
                constructorFn,
                mode,
                dependencies,
                singletonInstance,
                alias
            });
        }
        return ServiceProvider;
    }
    static getInfo(constructorFn) {
        const inject = ServiceProvider.app.find(e => e.constructorFn == constructorFn);
        if (!inject) {
            throw errorBuilder_1.ErrorBuilder.notFound("Inject not found");
        }
        return inject;
    }
    static getInstance(constructorFn) {
        return ServiceProvider.injectableRegistry.get(constructorFn);
    }
    static setInstance(constructorFn, instance) {
        ServiceProvider.injectableRegistry.set(constructorFn, instance);
    }
    static config(config) {
        ServiceProvider.setInstance(configuration_1.Configuration, config);
        const event = ServiceProvider.getInstance(events_1.default);
        event.emit("configuration");
    }
}
exports.ServiceProvider = ServiceProvider;
ServiceProvider.app = [];
ServiceProvider.injectableRegistry = injector_1.injector;
