"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MigratorAplication = void 0;
require("reflect-metadata");
const dotenv_1 = __importDefault(require("dotenv"));
const configuration_1 = require("../configs/configuration");
const errorBuilder_1 = require("../errorBuilder");
const SqlMigrator_1 = require("./SqlMigrator");
const connections_1 = require("../connections");
const di_1 = require("../di");
const metadata_1 = require("../metadata");
dotenv_1.default.config();
class MigratorAplication {
    constructor(config, pathDir = "/migrations") {
        this.config = config;
        this.pathDir = pathDir;
        di_1.ServiceProvider.setInstance(configuration_1.Configuration, config);
    }
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            yield di_1.ServiceProvider.getInstance(connections_1.DatabaseConnection).init(this.config.DB_CONFIG);
            const dbConnection = di_1.ServiceProvider.getInstance(metadata_1.Metadata).dbConnection;
            if (!dbConnection) {
                throw errorBuilder_1.ErrorBuilder.notFound("Database connection not found");
            }
            const sqlMigrator = new SqlMigrator_1.SqlMigrator(dbConnection, this.pathDir);
            yield sqlMigrator.execuseCommand();
        });
    }
}
exports.MigratorAplication = MigratorAplication;
