"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MigratorCommand = exports.metaTableDefinition = exports.MIGRATION_ROLE_PERMISSION_TEMPLATE = exports.MIGRATION_TEMPLATE = void 0;
const sequelize_1 = require("sequelize");
exports.MIGRATION_TEMPLATE = `
    import { DataTypes, QueryInterface, Transaction } from "@fasterjs/core";

    export default {
        up: async (queryInterface: QueryInterface, t: Transaction) => {
            /** no-op */
        },
        down: async (queryInterface: QueryInterface, t: Transaction) => {
            /** no-op */
        },
    };
`;
exports.MIGRATION_ROLE_PERMISSION_TEMPLATE = `
    import { DataTypes, QueryInterface, Transaction, Configuration, ServiceProvider, Config } from "@fasterjs/core";

    export default {
        up: async (queryInterface: QueryInterface, t: Transaction) => {
            /** no-op */
            const config = ServiceProvider.getInstance(Configuration) as Config;
            const tableRole = config.ROLE_AND_PERMISSION?.TABLE_ROLE || "Roles"
            const tablePermission = config.ROLE_AND_PERMISSION?.TABLE_PERMISSION || "Permissions"
            const tableRolePermission = config.ROLE_AND_PERMISSION?.TABLE_ROLE_PERMISSION || "RoleHasPermissions"

            await queryInterface.createTable(tableRole, {
                id: { primaryKey: true, allowNull: false, type: DataTypes.STRING(50) },
                name: { allowNull: false, type: DataTypes.STRING(200) },
                createdAt: {
                    allowNull: false, type: DataTypes.BIGINT({
                        unsigned: true,
                    })
                },
                updatedAt: {
                    allowNull: false, type: DataTypes.BIGINT({
                        unsigned: true,
                    })
                }
            }, {
                transaction: t
            })

            await queryInterface.createTable(tablePermission, {
                id: { primaryKey: true, allowNull: false, type: DataTypes.STRING(50) },
                name: { allowNull: false, type: DataTypes.STRING(200) },
                method: { allowNull: false, type: DataTypes.STRING(10) },
                api: { allowNull: false, type: DataTypes.STRING(300) },
                createdAt: {
                    allowNull: false, type: DataTypes.BIGINT({
                        unsigned: true,
                    })
                },
                updatedAt: {
                    allowNull: false, type: DataTypes.BIGINT({
                        unsigned: true,
                    })
                }
            }, {
                transaction: t
            })

            await queryInterface.createTable(tableRolePermission, {
                id: { primaryKey: true, allowNull: false, type: DataTypes.STRING(50) },
                roleId: { allowNull: false, type: DataTypes.STRING(50) },
                permissionId: { allowNull: false, type: DataTypes.STRING(50) },
                createdAt: {
                    allowNull: false, type: DataTypes.BIGINT({
                        unsigned: true,
                    })
                },
                updatedAt: {
                    allowNull: false, type: DataTypes.BIGINT({
                        unsigned: true,
                    })
                }
            }, {
                transaction: t
            })

            await queryInterface.addConstraint(tableRolePermission, {
                fields: ["roleId"],
                type: "foreign key",
                name: tableRolePermission + "_roleId_fk",
                references: {
                    table: tableRole,
                    field: "id",
                },
                onDelete: "CASCADE",
                onUpdate: "CASCADE",
                transaction: t
            })

            await queryInterface.addConstraint(tableRolePermission, {
                fields: ["permissionId"],
                type: "foreign key",
                name: tableRolePermission + "_permissionId_fk",
                references: {
                    table: tablePermission,
                    field: "id",
                },
                onDelete: "CASCADE",
                onUpdate: "CASCADE",
                transaction: t
            })

        },
        down: async (queryInterface: QueryInterface, t: Transaction) => {
            /** no-op */
            const config = ServiceProvider.getInstance(Configuration) as Config;
            const tableRole = config.ROLE_AND_PERMISSION?.TABLE_ROLE || "Roles"
            const tablePermission = config.ROLE_AND_PERMISSION?.TABLE_PERMISSION || "Permissions"
            const tableRolePermission = config.ROLE_AND_PERMISSION?.TABLE_ROLE_PERMISSION || "RoleHasPermissions"

            await queryInterface.removeConstraint(tableRolePermission, tableRolePermission + "_permissionId_fk", { transaction: t })
            await queryInterface.removeConstraint(tableRolePermission, tableRolePermission+ "_roleId_fk", { transaction: t })
            await queryInterface.dropTable(tableRolePermission, { transaction: t })
            await queryInterface.dropTable(tablePermission, { transaction: t })
            await queryInterface.dropTable(tableRole, { transaction: t })
        },
    };
`;
exports.metaTableDefinition = {
    name: { primaryKey: true, allowNull: false, type: sequelize_1.DataTypes.STRING(255) }
};
var MigratorCommand;
(function (MigratorCommand) {
    MigratorCommand["MAKE_ROLE_AND_PERMISSION"] = "makeRAP";
    MigratorCommand["GENERATE"] = "generate";
    MigratorCommand["UPGRADE"] = "up";
    MigratorCommand["DOWNGRADE"] = "down";
})(MigratorCommand || (exports.MigratorCommand = MigratorCommand = {}));
