import { QueryCondition, FindOptions, ModelQuery, Op, OpSpecial, OpArray, SelectColumns } from "./interfaces/QueryCondition";
import { IQueryBuilder } from "./interfaces/IQueryBuilder";
import { WithRelation } from "./interfaces/WithRelation";
import { Constructor, Table } from "../decorators";
import { Sequelize, Transaction } from "sequelize";
import { QueryBuilder } from ".";
import { IPagination } from "../global";
export declare class SqlQueryBuilder<T> implements IQueryBuilder<T> {
    readonly db: Sequelize;
    readonly table: Table;
    readonly sqlProvider: "mysql" | "postgres";
    withRelations: WithRelation<T, any>[];
    selectColumns: SelectColumns<T>;
    constructor(db: Sequelize, table: Table, sqlProvider: "mysql" | "postgres");
    generateWith<K>(params: WithRelation<T, K> | WithRelation<T, K>[], model: Constructor<QueryBuilder<T>>): WithRelation<T, any>[];
    with<K>(params: WithRelation<T, K> | WithRelation<T, K>[], model: QueryBuilder<T>): void;
    private generateInclude;
    private getCollection;
    findByPk(pk: string | number): Promise<ModelQuery<T> | null>;
    find(filter: QueryCondition<ModelQuery<T>>, options?: FindOptions<ModelQuery<T>>): Promise<ModelQuery<T>[]>;
    paginate(filter: QueryCondition<ModelQuery<T>>, paginate: IPagination, options?: Omit<FindOptions<ModelQuery<T>>, "group">): Promise<{
        data: ModelQuery<T>[];
        totalCount: number;
    }>;
    count(filter: QueryCondition<ModelQuery<T>>): Promise<number>;
    createOne(item: Partial<ModelQuery<T>>, options?: {
        transaction?: Transaction;
    }): Promise<ModelQuery<T>>;
    updateMany(filter: QueryCondition<ModelQuery<T>>, item: Partial<ModelQuery<T>>, options?: {
        transaction?: Transaction;
    }): Promise<[affectedCount: number]>;
    deleteOne(filter: QueryCondition<ModelQuery<T>>, options?: {
        transaction?: Transaction;
    }): Promise<number | never[]>;
    deleteMany(filter: QueryCondition<ModelQuery<T>>, options?: {
        transaction?: Transaction;
    }): Promise<number>;
    select(selectColumns: SelectColumns<T>): void;
    reset(): void;
    mapToSequelizeOperator(op: Op | OpSpecial | OpArray, attribute: keyof ModelQuery<T>, value: T[keyof ModelQuery<T>], usingLiteral?: boolean): any;
    getQueryObjectFromQueryConditions(queries: QueryCondition<T>, usingLiteral?: boolean): {
        [x: string]: any;
    };
}
